@@ -117,17 +117,14 @@ from __future__ import annotations
 
 import itertools
 import logging
-from typing import TYPE_CHECKING, Union, cast
+from typing import Iterable, Union
 
 from rdflib.collection import Collection
 from rdflib.graph import Graph, _ObjectType
 from rdflib.namespace import OWL, RDF, RDFS, XSD, Namespace, NamespaceManager
-from rdflib.term import BNode, IdentifiedNode, Identifier, Literal, URIRef, Variable
+from rdflib.term import BNode, Identifier, Literal, URIRef, Variable
 from rdflib.util import first
 
-if TYPE_CHECKING:
-    from collections.abc import Iterable
-
 logger = logging.getLogger(__name__)
 
 
@@ -374,19 +371,13 @@ class Individual:
 
     """
 
-    # Class variable
     factoryGraph = Graph()  # noqa: N815
 
-    # Instance typing
-    graph: Graph
-    __identifier: IdentifiedNode
-    qname: str | None
-
     def serialize(self, graph):
         for fact in self.factoryGraph.triples((self.identifier, None, None)):
             graph.add(fact)
 
-    def __init__(self, identifier: IdentifiedNode | None = None, graph=None):
+    def __init__(self, identifier=None, graph=None):
         self.__identifier = identifier is not None and identifier or BNode()
         if graph is None:
             self.graph = self.factoryGraph
@@ -474,10 +465,11 @@ class Individual:
 
     type = property(_get_type, _set_type, _delete_type)
 
-    def _get_identifier(self) -> IdentifiedNode:
+    def _get_identifier(self) -> Identifier:
         return self.__identifier
 
-    def _set_identifier(self, i: IdentifiedNode):
+    def _set_identifier(self, i: Identifier):
+        assert i
         if i != self.__identifier:
             oldstatements_out = [
                 (p, o)
@@ -605,7 +597,7 @@ class AnnotatableTerms(Individual):
 
     def __init__(
         self,
-        identifier: IdentifiedNode | None,
+        identifier,
         graph=None,
         nameAnnotation=None,  # noqa: N803
         nameIsLabel=False,  # noqa: N803
@@ -661,13 +653,10 @@ class AnnotatableTerms(Individual):
         ):
             yield comment
 
-    def _set_comment(
-        self,
-        comment: IdentifiedNode | Literal | list[IdentifiedNode | Literal] | None,
-    ):
+    def _set_comment(self, comment):
         if not comment:
             return
-        if isinstance(comment, (IdentifiedNode, Literal)):
+        if isinstance(comment, Identifier):
             self.graph.add((self.identifier, RDFS.comment, comment))
         else:
             for c in comment:
@@ -701,12 +690,10 @@ class AnnotatableTerms(Individual):
         for label in self.graph.objects(subject=self.identifier, predicate=RDFS.label):
             yield label
 
-    def _set_label(
-        self, label: IdentifiedNode | Literal | list[IdentifiedNode | Literal] | None
-    ):
+    def _set_label(self, label):
         if not label:
             return
-        if isinstance(label, (IdentifiedNode, Literal)):
+        if isinstance(label, Identifier):
             self.graph.add((self.identifier, RDFS.label, label))
         else:
             for l_ in label:
@@ -1058,7 +1045,7 @@ class Class(AnnotatableTerms):
 
     def __init__(
         self,
-        identifier: IdentifiedNode | None = None,
+        identifier=None,
         subClassOf=None,  # noqa: N803
         equivalentClass=None,  # noqa: N803
         disjointWith=None,  # noqa: N803
@@ -1187,10 +1174,7 @@ class Class(AnnotatableTerms):
         for anc in self.graph.objects(
             subject=self.identifier, predicate=RDFS.subClassOf
         ):
-            # We must assume all objects we get back are URIRef or BNodes
-            yield Class(
-                cast(IdentifiedNode, anc), graph=self.graph, skipOWLClassMembership=True
-            )
+            yield Class(anc, graph=self.graph, skipOWLClassMembership=True)
 
     def _set_subclassof(self, other):
         if not other:
@@ -1210,7 +1194,7 @@ class Class(AnnotatableTerms):
         for ec in self.graph.objects(
             subject=self.identifier, predicate=OWL.equivalentClass
         ):
-            yield Class(cast(IdentifiedNode, ec), graph=self.graph)
+            yield Class(ec, graph=self.graph)
 
     def _set_equivalentclass(self, other):
         if not other:
@@ -1232,7 +1216,7 @@ class Class(AnnotatableTerms):
         for dc in self.graph.objects(
             subject=self.identifier, predicate=OWL.disjointWith
         ):
-            yield Class(cast(IdentifiedNode, dc), graph=self.graph)
+            yield Class(dc, graph=self.graph)
 
     def _set_disjointwith(self, other):
         if not other:
@@ -1255,7 +1239,7 @@ class Class(AnnotatableTerms):
         if not comp:
             return None
         elif len(comp) == 1:
-            return Class(cast(IdentifiedNode, comp[0]), graph=self.graph)
+            return Class(comp[0], graph=self.graph)
         else:
             raise Exception(len(comp))
 
@@ -1326,7 +1310,7 @@ class Class(AnnotatableTerms):
         # sc = list(self.subClassOf)
         ec = list(self.equivalentClass)
         for _boolclass, p, rdf_list in self.graph.triples_choices(
-            # type error: Argument 1 to "triples_choices" of "Graph" has incompatible type "Tuple[Any, list[URIRef], None]"; expected "Union[Tuple[List[Node], Node, Node], tuple[Node, list[Node], Node], tuple[Node, Node, list[Node]]]"
+            # type error: Argument 1 to "triples_choices" of "Graph" has incompatible type "Tuple[Any, List[URIRef], None]"; expected "Union[Tuple[List[Node], Node, Node], Tuple[Node, List[Node], Node], Tuple[Node, Node, List[Node]]]"
             (self.identifier, [OWL.intersectionOf, OWL.unionOf], None)  # type: ignore[arg-type]
         ):
             ec.append(manchesterSyntax(rdf_list, self.graph, boolean=p))
@@ -1356,7 +1340,7 @@ class Class(AnnotatableTerms):
         sc = list(self.subClassOf)
         ec = list(self.equivalentClass)
         for _boolclass, p, rdf_list in self.graph.triples_choices(
-            # type error: Argument 1 to "triples_choices" of "Graph" has incompatible type "Tuple[Any, list[URIRef], None]"; expected "Union[Tuple[List[Node], Node, Node], tuple[Node, list[Node], Node], tuple[Node, Node, list[Node]]]"
+            # type error: Argument 1 to "triples_choices" of "Graph" has incompatible type "Tuple[Any, List[URIRef], None]"; expected "Union[Tuple[List[Node], Node, Node], Tuple[Node, List[Node], Node], Tuple[Node, Node, List[Node]]]"
             (self.identifier, [OWL.intersectionOf, OWL.unionOf], None)  # type: ignore[arg-type]
         ):
             ec.append(manchesterSyntax(rdf_list, self.graph, boolean=p))
@@ -1365,8 +1349,10 @@ class Class(AnnotatableTerms):
         if c:
             dc.append(c)
         klasskind = ""
-        label_list = list(self.graph.objects(self.identifier, RDFS.label))
-        label = "" if len(label_list) < 1 else "(" + label_list[0] + ")"
+        label = list(self.graph.objects(self.identifier, RDFS.label))
+        # type error: Incompatible types in assignment (expression has type "str", variable has type "List[Node]")
+        # type error: Unsupported operand types for + ("str" and "Node")
+        label = label and "(" + label[0] + ")" or ""  # type: ignore[assignment, operator]
         if sc:
             if full:
                 scjoin = "\n                "
@@ -1762,34 +1748,27 @@ class Restriction(Class):
     def __init__(
         self,
         onProperty,  # noqa: N803
-        graph: Graph | None = None,
-        allValuesFrom: (  # noqa: N803
-            IdentifiedNode | Literal | Class | bool | None
-        ) = None,
-        someValuesFrom: (  # noqa: N803
-            IdentifiedNode | Literal | Class | bool | None
-        ) = None,
-        value: IdentifiedNode | Literal | Class | bool | None = None,
-        cardinality: IdentifiedNode | Literal | Class | bool | None = None,
-        maxCardinality: (  # noqa: N803
-            IdentifiedNode | Literal | Class | bool | None
-        ) = None,
-        minCardinality: (  # noqa: N803
-            IdentifiedNode | Literal | Class | bool | None
-        ) = None,
-        identifier: IdentifiedNode | None = None,
+        graph=None,
+        allValuesFrom=None,  # noqa: N803
+        someValuesFrom=None,  # noqa: N803
+        value=None,
+        cardinality=None,
+        maxCardinality=None,  # noqa: N803
+        minCardinality=None,  # noqa: N803
+        identifier=None,
     ):
         graph = Graph() if graph is None else graph
         super(Restriction, self).__init__(
             identifier, graph=graph, skipOWLClassMembership=True
         )
-        self_id_node: IdentifiedNode = self.identifier
         if (
-            self_id_node,
+            self.identifier,
             OWL.onProperty,
             propertyOrIdentifier(onProperty),
         ) not in graph:
-            graph.add((self_id_node, OWL.onProperty, propertyOrIdentifier(onProperty)))
+            graph.add(
+                (self.identifier, OWL.onProperty, propertyOrIdentifier(onProperty))
+            )
         self.onProperty = onProperty
         restr_types = [
             (allValuesFrom, OWL.allValuesFrom),
@@ -1808,7 +1787,7 @@ class Restriction(Class):
             )
         restriction_range, restriction_type = valid_restr_props.pop()
         self.restrictionType = restriction_type
-        if isinstance(restriction_range, (IdentifiedNode, Literal)):
+        if isinstance(restriction_range, Identifier):
             self.restrictionRange = restriction_range
         elif isinstance(restriction_range, Class):
             self.restrictionRange = classOrIdentifier(restriction_range)
@@ -1816,18 +1795,18 @@ class Restriction(Class):
             # error: Incompatible types in assignment (expression has type "Optional[Identifier]", variable has type "Identifier")
             self.restrictionRange = first(  # type: ignore[assignment]
                 # type error: Argument 1 to "first" has incompatible type "Generator[Node, None, None]"; expected "Iterable[Identifier]"
-                self.graph.objects(self_id_node, restriction_type)  # type: ignore[arg-type]
+                self.graph.objects(self.identifier, restriction_type)  # type: ignore[arg-type]
             )
         if (
-            self_id_node,
+            self.identifier,
             restriction_type,
             self.restrictionRange,
         ) not in self.graph:
-            self.graph.add((self_id_node, restriction_type, self.restrictionRange))
-        assert self.restrictionRange is not None, Class(self_id_node)
-        if (self_id_node, RDF.type, OWL.Restriction) not in self.graph:
-            self.graph.add((self_id_node, RDF.type, OWL.Restriction))
-            self.graph.remove((self_id_node, RDF.type, OWL.Class))
+            self.graph.add((self.identifier, restriction_type, self.restrictionRange))
+        assert self.restrictionRange is not None, Class(self.identifier)
+        if (self.identifier, RDF.type, OWL.Restriction) not in self.graph:
+            self.graph.add((self.identifier, RDF.type, OWL.Restriction))
+            self.graph.remove((self.identifier, RDF.type, OWL.Class))
 
     def serialize(self, graph):
         """
@@ -1904,7 +1883,7 @@ class Restriction(Class):
         for i in self.graph.objects(
             subject=self.identifier, predicate=OWL.allValuesFrom
         ):
-            return Class(cast(IdentifiedNode, i), graph=self.graph)
+            return Class(i, graph=self.graph)
         return None
 
     def _set_allvaluesfrom(self, other):
@@ -1928,7 +1907,7 @@ class Restriction(Class):
         for i in self.graph.objects(
             subject=self.identifier, predicate=OWL.someValuesFrom
         ):
-            return Class(cast(IdentifiedNode, i), graph=self.graph)
+            return Class(i, graph=self.graph)
         return None
 
     def _set_somevaluesfrom(self, other):
@@ -1950,7 +1929,7 @@ class Restriction(Class):
 
     def _get_hasvalue(self):
         for i in self.graph.objects(subject=self.identifier, predicate=OWL.hasValue):
-            return Class(cast(IdentifiedNode, i), graph=self.graph)
+            return Class(i, graph=self.graph)
         return None
 
     def _set_hasvalue(self, other):
@@ -1970,7 +1949,7 @@ class Restriction(Class):
 
     def _get_cardinality(self):
         for i in self.graph.objects(subject=self.identifier, predicate=OWL.cardinality):
-            return Class(cast(IdentifiedNode, i), graph=self.graph)
+            return Class(i, graph=self.graph)
         return None
 
     def _set_cardinality(self, other):
@@ -1992,7 +1971,7 @@ class Restriction(Class):
         for i in self.graph.objects(
             subject=self.identifier, predicate=OWL.maxCardinality
         ):
-            return Class(cast(IdentifiedNode, i), graph=self.graph)
+            return Class(i, graph=self.graph)
         return None
 
     def _set_maxcardinality(self, other):
@@ -2016,7 +1995,7 @@ class Restriction(Class):
         for i in self.graph.objects(
             subject=self.identifier, predicate=OWL.minCardinality
         ):
-            return Class(cast(IdentifiedNode, i), graph=self.graph)
+            return Class(i, graph=self.graph)
         return None
 
     def _set_mincardinality(self, other):
@@ -2037,12 +2016,12 @@ class Restriction(Class):
     )
 
     def restrictionKind(self):  # noqa: N802
-        self_id_node: IdentifiedNode = self.identifier
         for s, p, o in self.graph.triples_choices(
-            # type error: Argument 1 to "triples_choices" of "Graph" has incompatible type
-            (self_id_node, self.restrictionKinds, None)  # type: ignore[arg-type]
+            # type error: Argument 1 to "triples_choices" of "Graph" has incompatible type "Tuple[Any, List[URIRef], None]"; expected "Union[Tuple[List[Node], Node, Node], Tuple[Node, List[Node], Node], Tuple[Node, Node, List[Node]]]"
+            (self.identifier, self.restrictionKinds, None)  # type: ignore[arg-type]
         ):
-            return p.split(str(OWL))[-1]
+            # type error: "Node" has no attribute "split"
+            return p.split(str(OWL))[-1]  # type: ignore[attr-defined]
         return None
 
     def __repr__(self):
@@ -2211,7 +2190,7 @@ class Property(AnnotatableTerms):
                     )
                 )
             for _s, _p, roletype in self.graph.triples_choices(
-                # type error: Argument 1 to "triples_choices" of "Graph" has incompatible type "Tuple[Any, URIRef, list[URIRef]]"; expected "Union[Tuple[List[Node], Node, Node], tuple[Node, list[Node], Node], tuple[Node, Node, list[Node]]]"
+                # type error: Argument 1 to "triples_choices" of "Graph" has incompatible type "Tuple[Any, URIRef, List[URIRef]]"; expected "Union[Tuple[List[Node], Node, Node], Tuple[Node, List[Node], Node], Tuple[Node, Node, List[Node]]]"
                 (  # type: ignore[arg-type]
                     self.identifier,
                     RDF.type,
@@ -2222,7 +2201,8 @@ class Property(AnnotatableTerms):
                     ],
                 )
             ):
-                rt.append(str(roletype).split(str(OWL), 1)[-1])
+                # type error: "Node" has no attribute "split"
+                rt.append(str(roletype.split(str(OWL))[-1]))  # type: ignore[attr-defined]
         else:
             rt.append(
                 "DatatypeProperty( %s %s"
@@ -2316,7 +2296,7 @@ class Property(AnnotatableTerms):
 
     def _get_domain(self):
         for dom in self.graph.objects(subject=self.identifier, predicate=RDFS.domain):
-            yield Class(cast(IdentifiedNode, dom), graph=self.graph)
+            yield Class(dom, graph=self.graph)
 
     def _set_domain(self, other):
         if not other:
@@ -2335,7 +2315,7 @@ class Property(AnnotatableTerms):
 
     def _get_range(self):
         for ran in self.graph.objects(subject=self.identifier, predicate=RDFS.range):
-            yield Class(cast(IdentifiedNode, ran), graph=self.graph)
+            yield Class(ran, graph=self.graph)
 
     def _set_range(self, ranges):
         if not ranges:
